- time
survival times, a numeric vector.
time[i] is the survival time of the ith sample.
- event
survival events, a logical vector.
event[i] is the survival event of the ith sample.
- matrix_numeric
numeric predictors, a numeric matrix.
matrix_numeric[i,j] is the jth numeric predictor of the ith sample.
- matrix_factor
factor predictors, a character matrix.
matrix_factor[i,j] is the jth predictor of the ith sample.
- weights
sample weights, a numeric vector.
weights[i] is the weight of the ith sample.
- significance
significance threshold, a numeric value.
Stop the splitting algorithm when no splits give a p-value smaller than significance.
- min_weights
minimum weight threshold, a numeric value.
The weights in a node are greater than min_weights.
- missing
a character value that specifies the handling of missing data.
If missing=="omit", samples with missing values in the splitting variables will be discarded.
If missing=="majority", samples with missing values in the splitting variables will be assigned to the majority node.
If missing=="weighted", samples with missing values in the splitting variables will be weighted by the weights of branch nodes.
- test_type
a character value that specifies the type of statistical tests.
If test_type=="univariate", then it performs a log-rank test without p-value adjustments.
If test_type is in p.adjust.methods, i.e., one of holm, hochberg, hommel, bonferroni, BH, BY, or fdr,
then the p-values will be adjusted using the corresponding method.
- cut_type
an integer value that specifies how to cut between two numeric values.
If cut_type==0, then cut at the ends.
If cut_type==1, then cut from the middle.
If cut_type==2, then cut randomly between the two values.